@@ -1,9 +1,19 @@
+import datetime
 import json
-from typing import Dict
+from typing import Dict, Iterator, Union
 
 from python_on_whales.client_config import DockerCLICaller
-from python_on_whales.components.system.models import DockerItemsSummary, SystemInfo
-from python_on_whales.utils import format_dict_for_cli, run
+from python_on_whales.components.system.models import (
+    DockerEvent,
+    DockerItemsSummary,
+    SystemInfo,
+)
+from python_on_whales.utils import (
+    format_dict_for_cli,
+    format_time_arg,
+    run,
+    stream_stdout_and_stderr,
+)
 
 
 class DiskFreeResult:
@@ -57,9 +67,66 @@ class SystemCLI(DockerCLICaller):
         full_cmd = self.docker_cmd + ["system", "df", "--format", "{{json .}}"]
         return DiskFreeResult(run(full_cmd))
 
-    def events(self):
-        """Not yet implemented"""
-        raise NotImplementedError
+    def events(
+        self,
+        since: Union[None, datetime.datetime, datetime.timedelta] = None,
+        until: Union[None, datetime.datetime, datetime.timedelta] = None,
+        filters: Dict[str, str] = {},
+    ) -> Iterator[DockerEvent]:
+        """Return docker events information up to the current point in time.
+
+        If `until` is not specified, then the iterator returned is infinite.
+        For example
+
+        ```python
+        from python_on_whales import docker
+        from datetime import datetime, timedelta
+
+
+        for event in docker.system.events():
+            print("new event!")
+            print(event)
+            # this will never end, that's ok if you want to monitor something
+            # for a long time. You can also use 'break' in the for loop if needed.
+
+        for event in docker.system.events(until=datetime.now() - timedelta(seconds=30)):
+            print("some past event")
+            print(event)
+            # this loop will end, unlike the previous one
+
+        for event in docker.system.events(until=datetime.now() + timedelta(seconds=30)):
+            print("some past event")
+            print(event)
+            # this loop will end in 30 seconds, even if there are no events at all
+
+        events = list(docker.system.events(filters={"container": "mycontainer"}, until=datetime.now()))
+        # the list of all events concerning the container "mycontainer"
+        ```
+
+        # Arguments
+            since:  Show all events created since timestamp
+            until: 	Stream events until this timestamp
+            filters: See the [Docker documentation page about filtering
+                ](https://docs.docker.com/engine/reference/commandline/events/#filtering).
+        # Returns
+            A iterator which will yield DockerEvent objects from stdout/stderr
+
+        [reference page for
+        system events](https://docs.docker.com/engine/api/v1.40/#operation/SystemEvents)
+        """
+        full_cmd = self.docker_cmd + [
+            "system",
+            "events",
+            "--format",
+            "{{json .}}",
+        ]
+        full_cmd.add_simple_arg("--since", format_time_arg(since))
+        full_cmd.add_simple_arg("--until", format_time_arg(until))
+        full_cmd.add_args_list("--filter", format_dict_for_cli(filters))
+        iterator = stream_stdout_and_stderr(full_cmd)
+        for stream_origin, stream_content in iterator:
+            if stream_origin == "stdout":
+                yield DockerEvent.parse_raw(stream_content)
 
     def info(self) -> SystemInfo:
         """Returns diverse information about the Docker client and daemon.
